import { URI } from '@vscode/monaco-editor/esm/vs/base/common/uri';
import { Event } from '@vscode/monaco-editor/esm/vs/base/common/event';
import { IContent, IStreamContent } from './files-content';
import { IResolveContentOptions, IUpdateContentOptions, IResolveFileOptions, ICreateFileOptions } from './options';
import { IFileStat, IFileSystemProviderRegistrationEvent, IResolveFileResult, IFileSystemProvider } from './files';
import { ITextSnapshot } from './text-snapshot';
import { FileChangesEvent, FileOperationEvent } from '../events';
import { IDisposable } from '@vscode/monaco-editor/esm/vs/base/common/lifecycle';
export interface IResourceEncodings {
    getWriteEncoding(resource: URI, preferredEncoding?: string): string;
}
export interface IFileService {
    /**
     * Helper to determine read/write encoding for resources.
     */
    encoding: IResourceEncodings | Promise<IResourceEncodings>;
    /**
     * Allows to listen for file changes. The event will fire for every file within the opened workspace
     * (if any) as well as all files that have been watched explicitly using the #watchFileChanges() API.
     */
    onFileChanges: Event<FileChangesEvent>;
    /**
     * An event that is fired upon successful completion of a certain file operation.
     */
    onAfterOperation: Event<FileOperationEvent>;
    /**
     * An event that is fired when a file system provider is added or removed
     */
    onDidChangeFileSystemProviderRegistrations: Event<IFileSystemProviderRegistrationEvent>;
    /**
     * Registeres a file system provider for a certain scheme.
     */
    registerProvider(scheme: string, provider: IFileSystemProvider): IDisposable | Promise<IDisposable>;
    /**
     * Tries to activate a provider with the given scheme.
     */
    activateProvider(scheme: string): Promise<void>;
    /**
     * Checks if this file service can handle the given resource.
     */
    canHandleResource(resource: URI): boolean | Promise<boolean>;
    /**
     * Resolve the properties of a file identified by the resource.
     *
     * If the optional parameter "resolveTo" is specified in options, the stat service is asked
     * to provide a stat object that should contain the full graph of folders up to all of the
     * target resources.
     *
     * If the optional parameter "resolveSingleChildDescendants" is specified in options,
     * the stat service is asked to automatically resolve child folders that only
     * contain a single element.
     */
    resolveFile(resource: URI, options?: IResolveFileOptions): Promise<IFileStat>;
    /**
     * Same as resolveFile but supports resolving multiple resources in parallel.
     * If one of the resolve targets fails to resolve returns a fake IFileStat instead of making the whole call fail.
     */
    resolveFiles(toResolve: {
        resource: URI;
        options?: IResolveFileOptions;
    }[]): Promise<IResolveFileResult[]>;
    /**
     *Finds out if a file identified by the resource exists.
     */
    existsFile(resource: URI): Promise<boolean>;
    /**
     * Resolve the contents of a file identified by the resource.
     *
     * The returned object contains properties of the file and the full value as string.
     */
    resolveContent(resource: URI, options?: IResolveContentOptions): Promise<IContent>;
    /**
     * Resolve the contents of a file identified by the resource.
     *
     * The returned object contains properties of the file and the value as a readable stream.
     */
    resolveStreamContent(resource: URI, options?: IResolveContentOptions): Promise<IStreamContent>;
    /**
     * Updates the content replacing its previous value.
     */
    updateContent(resource: URI, value: string | ITextSnapshot, options?: IUpdateContentOptions): Promise<IFileStat>;
    /**
     * Moves the file to a new path identified by the resource.
     *
     * The optional parameter overwrite can be set to replace an existing file at the location.
     */
    moveFile(source: URI, target: URI, overwrite?: boolean): Promise<IFileStat>;
    /**
     * Copies the file to a path identified by the resource.
     *
     * The optional parameter overwrite can be set to replace an existing file at the location.
     */
    copyFile(source: URI, target: URI, overwrite?: boolean): Promise<IFileStat>;
    /**
     * Creates a new file with the given path. The returned promise
     * will have the stat model object as a result.
     *
     * The optional parameter content can be used as value to fill into the new file.
     */
    createFile(resource: URI, content?: string, options?: ICreateFileOptions): Promise<IFileStat>;
    /**
     * Creates a new folder with the given path. The returned promise
     * will have the stat model object as a result.
     */
    createFolder(resource: URI): Promise<IFileStat>;
    /**
     * Deletes the provided file. The optional useTrash parameter allows to
     * move the file to trash. The optional recursive parameter allows to delete
     * non-empty folders recursively.
     */
    del(resource: URI, options?: {
        useTrash?: boolean;
        recursive?: boolean;
    }): Promise<void>;
    /**
     * Allows to start a watcher that reports file change events on the provided resource.
     */
    watchFileChanges(resource: URI): void;
    /**
     * Allows to stop a watcher on the provided resource or absolute fs path.
     */
    unwatchFileChanges(resource: URI): void;
    /**
     * Frees up any resources occupied by this service.
     */
    dispose(): void;
}
