import { URI } from '@vscode/monaco-editor/esm/vs/base/common/uri';
import { Event } from '@vscode/monaco-editor/esm/vs/base/common/event';
import { IDisposable } from '@vscode/monaco-editor/esm/vs/base/common/lifecycle';
import { FileDeleteOptions, FileOverwriteOptions, FileWriteOptions, ICreateFileOptions, IWatchOptions, IUpdateContentOptions, IResolveContentOptions } from './options';
export declare enum FileOperation {
    CREATE = 0,
    DELETE = 1,
    MOVE = 2,
    COPY = 3
}
export interface IStat {
    id?: number | string;
    type: FileType;
    mtime: number;
    ctime: number;
    size: number;
}
export declare enum FileType {
    Unknown = 0,
    File = 1,
    Directory = 2,
    SymbolicLink = 64
}
export declare enum FileKind {
    FILE = 0,
    FOLDER = 1,
    ROOT_FOLDER = 2
}
export interface IEncodingOverride {
    resource: URI;
    encoding: string;
}
/**
 * Possible changes that can occur to a file.
 */
export declare enum FileChangeType {
    UPDATED = 0,
    ADDED = 1,
    DELETED = 2
}
/**
 * Idenfies a single change in a file.
 */
export interface IFileChange {
    /**
     * The type of change that occured to the file.
     */
    type: FileChangeType;
    /**
     * The unified resource identifier of the file that changed.
     */
    resource: URI;
}
export interface ICoreBaseStat {
    /**
     * The unified resource idnentifier of this file or folder.
     */
    resource: URI | string;
    /**
     * The name which is the last segement
     * of the {{path}}
     */
    name?: string;
    /**
     * @sri title additionally added
     */
    title?: string;
    /**
     * The last modification date represented
     * as millis from unix epoch.
     */
    mtime?: number;
    /**
     * A unique identifier that represents the
     * current state of the file or directory.
     */
    etag?: string;
    /**
     * The resource is readonly.
     */
    isReadonly?: boolean;
    size?: number;
}
/**
 * A file resource with meta information.
 */
export interface ICoreFileStat extends ICoreBaseStat {
    /**
     * The resource is a directory. If {{true}}
     * {{encoding}} has no meaning
     */
    isDirectory: boolean;
    /**
     * Return {{true}} when this is a directory
     * that is not empty.
     * @deprecated
     */
    hasChildren?: boolean;
    /**
     * The children of the file stat or undefined if none.
     */
    children?: ICoreFileStat[];
}
export interface IFileOperationResult {
    message: string;
    fileOperationResult: FileOperationResult;
}
export declare enum FileOperationResult {
    FILE_IS_BINARY = 0,
    FILE_IS_DIRECTORY = 1,
    FILE_NOT_FOUND = 2,
    FILE_NOT_MODIFIED_SINCE = 3,
    FILE_MODIFIED_SINCE = 4,
    FILE_MOVE_CONFLICT = 5,
    FILE_READ_ONLY = 6,
    FILE_PERMISSION_DENIED = 7,
    FILE_TOO_LARGE = 8,
    FILE_INVALID_PATH = 9,
    FILE_EXCEED_MEMORY_LIMIT = 10
}
export declare const AutoSaveConfiguration: {
    OFF: string;
    AFTER_DELAY: string;
    ON_FOCUS_CHANGE: string;
    ON_WINDOW_CHANGE: string;
};
export declare const HotExitConfiguration: {
    OFF: string;
    ON_EXIT: string;
    ON_EXIT_AND_WINDOW_CLOSE: string;
};
export interface IProgress<T> {
    report(item: T): void;
}
export declare const enum FileSystemProviderCapabilities {
    FileReadWrite = 2,
    FileOpenReadWriteClose = 4,
    FileFolderCopy = 8,
    PathCaseSensitive = 1024,
    Readonly = 2048
}
export interface IFileSystemProviderRegistrationEvent {
    added: boolean;
    scheme: string;
    provider?: IFileSystemProvider;
}
export interface IResolveFileResult {
    stat: IFileStat;
    success: boolean;
}
export interface IBaseStat extends ICoreBaseStat {
    resource: URI;
}
export interface IFileStat extends ICoreFileStat {
    resource: URI;
    /**
     * @deprecated
     */
    hasChildren?: boolean;
    /**
     * The resource is a directory. if {{true}}
     * {{encoding}} has no meaning.
     */
    isDirectory: boolean;
    /**
     * The resource is a symbolic link.
     */
    isSymbolicLink?: boolean;
    name?: string;
    /**
     * The children of the file stat or undefined if none.
     */
    children?: IFileStat[];
    /**
     * The size of the file if known.
     */
    size?: number;
    etag?: any;
    mtime?: any;
}
export interface IFileSystemProvider {
    readonly capabilities: FileSystemProviderCapabilities;
    onDidChangeFile: Event<IFileChange[]>;
    watch(resource: URI, opts: IWatchOptions): IDisposable;
    stat(resource: URI): Promise<IStat>;
    mkdir(resource: URI): Promise<void>;
    readdir(resource: URI): Promise<[string, FileType][]>;
    delete(resource: URI, opts: FileDeleteOptions): Promise<void>;
    rename(from: URI, to: URI, opts: FileOverwriteOptions): Promise<void>;
    copy?(from: URI, to: URI, opts: FileOverwriteOptions): Promise<void>;
    readFile?(resource: URI): Promise<Uint8Array>;
    writeFile?(resource: URI, content: Uint8Array, opts: FileWriteOptions): Promise<void>;
    open?(resource: URI): Promise<number>;
    close?(fd: number): Promise<void>;
    read?(fd: number, pos: number, data: Uint8Array, offset: number, length: number): Promise<number>;
    write?(fd: number, pos: number, data: Uint8Array, offset: number, length: number): Promise<number>;
}
export declare class FileOperationError extends Error {
    fileOperationResult: FileOperationResult;
    options?: IResolveContentOptions & IUpdateContentOptions & ICreateFileOptions;
    constructor(message: string, fileOperationResult: FileOperationResult, options?: IResolveContentOptions & IUpdateContentOptions & ICreateFileOptions);
    static isFileOperationError(obj: any): obj is FileOperationError;
}
export interface IImportResult {
    stat: IFileStat;
    isNew: boolean;
}
export interface IChunkOptions {
    piece: {
        range: {
            startLineNumber: number;
            startColumn: number;
            endLineNumber: number;
            endColumn: number;
        };
        rangeLength: number;
        part: number;
        text: string;
    };
    chunksCount: number;
    chunkPosition: number;
}
export interface IChangesChunk {
    range: {
        startLineNumber: number;
        startColumn: number;
        endLineNumber: number;
        endColumn: number;
    };
    text: string;
    rangeLength: number;
}
